@@ -621,10 +621,11 @@ class MultiHeadSelfAttentionWithCompressionState(nn.Module):
         for _ in range(max_new_tokens):
             # crop idx to the last sequence_len tokens
             idx_cond = idx[:, -self.sequence_len :]
+            state = state[:, -self.sequence_len :, :]
             # print(idx_cond.shape)
             # get the predictions
             logits, loss, state = self(
-                idx_cond, state=state[:, -idx_cond.shape[1] - 1 :]
+                idx_cond, state=state[:, -idx_cond.shape[1] :, :]
             )
             # focus only on the last time step
             logits = logits[:, -1, :]  # becomes (B, C)
@@ -640,4 +641,6 @@ class MultiHeadSelfAttentionWithCompressionState(nn.Module):
             idx_next = torch.multinomial(probs, num_samples=1)  # (B, 1)
             # append sampled index to the running sequence
             idx = torch.cat((idx, idx_next), dim=1)  # (B, T+1)
+            state = torch.cat((state, state[:, -1:, :]), dim=1)
+            # state[:, -1, :] = 0
         return idx, state
